@@ -915,6 +915,8 @@ class FixIBI(_Tool):
     def algorithm(cls, signal, params):
         assert isinstance(signal,
                           _UnevenlySignal), "IBI can only be represented by an UnevenlySignal, %s found." % type(signal)
+        
+        #TODO: if len of id_ibi is 0, avoid the following steps
         id_bad = params['id_bad_ibi']
         idx_ibi = signal.get_indices()
         ibi = signal.get_values()
@@ -1221,11 +1223,10 @@ class OptimizeBateman(_Tool):
             return None
 
         if complete:
-            x0_min, loss_min, niter,\
-            nfuncalls, warnflag, allvec = _opt.fmin(loss_function, x0,
+            opt_result = _opt.fmin(loss_function, x0,
                                                     args=(signal, delta),
                                                     full_output=True)
-            return x0, x0_min, loss, loss_min, exit_code, warnflag
+            return x0, loss, opt_result
         else:
             return x0, loss, exit_code
 
@@ -1404,7 +1405,7 @@ class OptimizeBateman(_Tool):
             if idx_grid[-1] != len(driver) - 1:
                 idx_grid = _np.r_[idx_grid, len(driver) - 1]
 
-            driver_grid = _UnevenlySignal(driver[idx_grid], fsamp, "dEDA", driver.get_start_time(), x_values=idx_grid,
+            driver_grid = _UnevenlySignal(driver[idx_grid], fsamp, driver.get_start_time(), x_values=idx_grid,
                                           x_type='indices', duration=signal.get_duration())
             if len(idx_grid) >= 4:
                 tonic = driver_grid.to_evenly(kind='cubic')
